@@ -1,4 +1,4 @@
-from enum import Enum, IntEnum
+from enum import Enum, IntEnum, Flag
 from sys import intern
 
 from .syntax import Name
@@ -108,6 +108,24 @@ class CoerciveIntEnum(IntEnum):
         raise TypeError(f"{value} cannot convert to a {cls.__name__}")
 
 
+class CharVPos(CoerciveEnum):
+    "Defines the vertical position of text relative to the line."
+    SUP = intern("SUP")
+    "Superscript"
+
+    SUB = intern("SUB")
+    "Subscript"
+
+    NOM = intern("NOM")
+    "Nominator of a fraction"
+
+    DENOM = intern("DENOM")
+    "Denominator of a fraction"
+
+    LINE = intern("LINE")
+    "Default line position"
+
+
 class Align(CoerciveEnum):
     "Defines how to render text in a cell"
 
@@ -408,6 +426,14 @@ class AnnotationName(CoerciveEnum):
     INSERT = Name("Insert")
 
 
+class FileAttachmentAnnotationName(CoerciveEnum):
+    "The name of an icon that shall be used in displaying the annotation"
+
+    PUSH_PIN = Name("PushPin")
+    GRAPH_PUSH_PIN = Name("GraphPushPin")
+    PAPERCLIP_TAG = Name("PaperclipTag")
+
+
 class IntersectionRule(CoerciveEnum):
     """
     An enumeration representing the two possible PDF intersection rules.
@@ -592,5 +618,34 @@ class Corner(CoerciveEnum):
     BOTTOM_LEFT = "BOTTOM_LEFT"
 
 
+class FontDescriptorFlags(Flag):
+    """An enumeration of the flags for the unsigned 32-bit integer entry in the font descriptor specifying various
+    characteristics of the font. Bit positions are numbered from 1 (low-order) to 32 (high-order)."""
+
+    FIXED_PITCH = 0x0000001
+    """
+    "All glyphs have the same width (as opposed to proportional or
+    variable-pitch fonts, which have different widths."
+    """
+
+    SYMBOLIC = 0x0000004
+    """
+    "Font contains glyphs outside the Adobe standard Latin character set.
+    This flag and the Nonsymbolic flag shall not both be set or both be clear."
+    """
+
+    ITALIC = 0x0000040
+    """
+    "Glyphs have dominant vertical strokes that are slanted."
+    """
+
+    FORCE_BOLD = 0x0040000
+    """
+    "The flag shall determine whether bold glyphs shall be painted with extra pixels even at very
+    small text sizes by a conforming reader. If set, features of bold glyphs may be thickened at
+    small text sizes."
+    """
+
+
 # This enum is only used internally:
 __pdoc__ = {"DocumentState": False}
