@@ -245,6 +245,8 @@ class HTML2FPDF(HTMLParser):
         self.table_row_height = 0
         self.heading_level = None
         self.heading_sizes = dict(**DEFAULT_HEADING_SIZES)
+        self.heading_above = 0.2  # extra space above heading, relative to font size
+        self.heading_below = 0.2  # extra space below heading, relative to font size
         if heading_sizes:
             self.heading_sizes.update(heading_sizes)
         self._only_imgs_in_td = False
@@ -399,7 +401,7 @@ class HTML2FPDF(HTMLParser):
             fill_color = self.pdf.fill_color
             self.pdf.set_fill_color(*bgcolor)
             self.pdf.rect(self.pdf.x, self.pdf.y, w, h, "F")
-            self.pdf.fill_color = fill_color
+            self.pdf.set_fill_color(*fill_color.colors)
 
     def output_table_header(self):
         if self.theader:
@@ -437,6 +439,10 @@ class HTML2FPDF(HTMLParser):
     def handle_starttag(self, tag, attrs):
         attrs = dict(attrs)
         LOGGER.debug("STARTTAG %s %s", tag, attrs)
+        if tag == "strong":
+            tag = "b"
+        if tag == "em":
+            tag = "i"
         if tag in ("b", "i", "u"):
             self.set_style(tag, True)
         if tag == "a":
@@ -452,8 +458,8 @@ class HTML2FPDF(HTMLParser):
             self.heading_level = int(tag[1:])
             hsize = self.heading_sizes[tag]
             self.pdf.set_text_color(150, 0, 0)
+            self.pdf.ln(self.h + self.heading_above * hsize)  # more space above heading
             self.set_font(size=hsize)
-            self.pdf.ln(self.h)
             if attrs:
                 self.align = attrs.get("align")
         if tag == "hr":
@@ -591,6 +597,10 @@ class HTML2FPDF(HTMLParser):
             self.pdf.insert_toc_placeholder(
                 self.render_toc, pages=int(attrs.get("pages", 1))
             )
+        if tag == "sup":
+            self.pdf.char_vpos = "SUP"
+        if tag == "sub":
+            self.pdf.char_vpos = "SUB"
 
     def handle_endtag(self, tag):
         # Closing tag
@@ -598,9 +608,11 @@ class HTML2FPDF(HTMLParser):
         if tag in self.heading_sizes:
             self.heading_level = None
             face, size, color = self.font_stack.pop()
+            self.pdf.ln(
+                self.h + self.h * self.heading_below
+            )  # more space below heading
             self.set_font(face, size)
             self.set_text_color(*color)
-            self.pdf.ln(self.h)
             self.align = None
         if tag == "pre":
             face, size, color = self.font_stack.pop()
@@ -664,6 +676,10 @@ class HTML2FPDF(HTMLParser):
             self.set_text_color(*self.font_color)
         if tag == "center":
             self.align = None
+        if tag == "sup":
+            self.pdf.char_vpos = "LINE"
+        if tag == "sub":
+            self.pdf.char_vpos = "LINE"
 
     def set_font(self, face=None, size=None):
         if face:
@@ -697,7 +713,6 @@ class HTML2FPDF(HTMLParser):
         self.set_style("u", False)
         self.set_text_color(*self.font_color)
 
-    # pylint: disable=no-self-use
     def render_toc(self, pdf, outline):
         "This method can be overriden by subclasses to customize the Table of Contents style."
         pdf.ln()
