@@ -3,7 +3,17 @@ from io import BytesIO
 import base64
 from urllib.request import urlopen
 
-from PIL import Image
+try:
+    from PIL import Image
+
+    try:
+        from PIL.Image import Resampling
+
+        RESAMPLE = Resampling.LANCZOS
+    except ImportError:  # For Pillow < 9.1.0
+        RESAMPLE = Image.ANTIALIAS
+except ImportError:
+    Image = None
 
 from .errors import FPDFException
 
@@ -44,15 +54,25 @@ def get_img_info(img, image_filter="AUTO", dims=None):
         img: `BytesIO` or `PIL.Image.Image` instance
         image_filter (str): one of the SUPPORTED_IMAGE_FILTERS
     """
+    if Image is None:
+        raise EnvironmentError("Pillow not available - fpdf2 cannot insert images")
+
     if not isinstance(img, Image.Image):
         img = Image.open(img)
+
     if dims:
-        img = img.resize(dims, resample=Image.Resampling.LANCZOS)
+        img = img.resize(dims, resample=RESAMPLE)
+
     if image_filter == "AUTO":
         # Very simple logic for now:
         image_filter = "DCTDecode" if img.format == "JPEG" else "FlateDecode"
-    if img.mode not in ("L", "LA", "RGB", "RGBA"):
+
+    if img.mode in ("P", "PA") and image_filter != "FlateDecode":
         img = img.convert("RGBA")
+
+    if img.mode not in ("L", "LA", "RGB", "RGBA", "P", "PA"):
+        img = img.convert("RGBA")
+
     w, h = img.size
     info = {}
     if img.mode == "L":
@@ -67,6 +87,30 @@ def get_img_info(img, image_filter="AUTO", dims=None):
             "JPXDecode",
         ):
             info["smask"] = _to_data(img, image_filter, select_slice=alpha_channel)
+    elif img.mode == "P":
+        dpn, bpc, colspace = 1, 8, "Indexed"
+        info["data"] = _to_data(img, image_filter)
+        info["pal"] = img.palette.palette
+
+        # check if the P image has transparency
+        if img.info.get("transparency", None) is not None and image_filter not in (
+            "DCTDecode",
+            "JPXDecode",
+        ):
+            # convert to RGBA to get the alpha channel for creating the smask
+            info["smask"] = _to_data(
+                img.convert("RGBA"), image_filter, select_slice=slice(3, None, 4)
+            )
+    elif img.mode == "PA":
+        dpn, bpc, colspace = 1, 8, "Indexed"
+        info["pal"] = img.palette.palette
+        alpha_channel = slice(1, None, 2)
+        info["data"] = _to_data(img, image_filter, remove_slice=alpha_channel)
+        if _has_alpha(img, alpha_channel) and image_filter not in (
+            "DCTDecode",
+            "JPXDecode",
+        ):
+            info["smask"] = _to_data(img, image_filter, select_slice=alpha_channel)
     elif img.mode == "RGB":
         dpn, bpc, colspace = 3, 8, "DeviceRGB"
         info["data"] = _to_data(img, image_filter)
@@ -90,7 +134,6 @@ def get_img_info(img, image_filter="AUTO", dims=None):
             "bpc": bpc,
             "f": image_filter,
             "dp": dp,
-            "pal": "",
             "trns": "",
         }
     )
@@ -101,18 +144,23 @@ def get_img_info(img, image_filter="AUTO", dims=None):
 def _to_data(img, image_filter, **kwargs):
     if image_filter == "FlateDecode":
         return _to_zdata(img, **kwargs)
+
     if img.mode == "LA":
         img = img.convert("L")
+
     if img.mode == "RGBA":
         img = img.convert("RGB")
+
     if image_filter == "DCTDecode":
         compressed_bytes = BytesIO()
         img.save(compressed_bytes, format="JPEG")
         return compressed_bytes.getvalue()
+
     if image_filter == "JPXDecode":
         compressed_bytes = BytesIO()
         img.save(compressed_bytes, format="JPEG2000")
         return compressed_bytes.getvalue()
+
     raise FPDFException(f'Unsupported image filter: "{image_filter}"')
 
 
