@@ -1,5 +1,5 @@
 import locale
-from datetime import datetime
+from datetime import datetime, timezone
 from typing import Union, Iterable
 
 
@@ -8,15 +8,15 @@ def object_id_for_page(page):
     return 2 * page + 1
 
 
-def substr(s, start, length=-1):
-    if length < 0:
-        length = len(s) - start
-    return s[start : start + length]
-
-
 def format_date(date: datetime, with_tz=False) -> str:
     if with_tz:
-        return enclose_in_parens(f"D:{date:%Y%m%d%H%M%SZ%H'%M'}")
+        assert date.tzinfo
+        if date.tzinfo == timezone.utc:
+            str_date = f"D:{date:%Y%m%d%H%M%SZ%H'%M'}"
+        else:
+            str_date = f"D:{date:%Y%m%d%H%M%S%z}"
+            str_date = str_date[:-2] + "'" + str_date[-2:] + "'"
+        return enclose_in_parens(str_date)
     return enclose_in_parens(f"D:{date:%Y%m%d%H%M%S}")
 
 
